// Java

package edu.washington.cac.myuw.servlet;

import java.io.*;
import java.util.*;
import edu.washington.cac.myuw.test.*;
  /** A file to print errors or informational messages

     This is a singleton class --- it cannot be instantiated, and only
     one Logfile object will ever exist.  On first reference, it will be
     initialized to System.err.  The filename can be changed, and whenever
     it is changed, it will redirect all standard error messages to the 
     file, so the class need only be referenced once 

    @author Greg Barnes
    @version 2.0
  */
public class Logfile {
  /** a unique id for a log file */
  private static String logName;

  /** the output stream of the logfile */
  public static PrintStream log;

  /** to start with, make the log System.err */
  static {
//%%%% below is a hack to fix timezone bug
TimeZone.setDefault(TimeZone.getTimeZone("PST"));
    log = System.err;
    logName = log.toString();
  }

    private synchronized static void initLog(String fileName) 
      throws IOException 
    {
	logName = fileName;
	Calendar cal = new GregorianCalendar();
	int curmonth = cal.get(Calendar.MONTH) + 1; 

	  // The following switches to a new log file each month
	String logfilename = fileName + cal.get(Calendar.YEAR) + 
	  (curmonth <10 ? 
	  "0" + Integer.toString(curmonth) : Integer.toString(curmonth))
	  + (edu.washington.cac.myuw.test.TestMode.isTestMode() ? ".test" : "");

	  // the second argument opens the file for appending
	log = new PrintStream(new FileOutputStream(logfilename, true));

	System.setErr(log);
    }

    static void changeLogName(String fileName)
      throws IOException 
    {
	if (fileName.equals(logName)) {
	    return;
	}

	if (log != null) {
	    log.close();
	}

	initLog(fileName);
    }

  private Logfile () {}
}
