package pubevents.addalerts;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;
import java.text.SimpleDateFormat;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.data.CaldataException;
import edu.washington.cac.calendar.data.Location;
import edu.washington.cac.calendar.data.Sponsor;
import edu.washington.cac.calendar.data.User;
import edu.washington.cac.calendar.db.DBResources;
import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.Queries;
import edu.washington.cac.calendar.db.Tables;

import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.updtalerts.UpdtAlerts;
import pubevents.util.ConvertRoutines;
import pubevents.util.PrintWebPage;

/** AddAlerts: add a new alert to database after editing is completed.
  
  @author Leman Chung, Greg Barnes
  @version 1.2
 */
public class AddAlerts
{
  public AddAlerts(HttpServletRequest req, 
                   HttpServletResponse res, 
                   String uid)
      throws CaldataException, IOException, SQLException 
  {
    res.setContentType("text/html");
    PrintWriter out = res.getWriter();
    SqlStatements sqlstmts = new SqlStatements ();
    PEParameter pep = new PEParameter(req);

    // 
    // set start date to current date, locationid and sponsorid to 1.
    // 
    try {    
      int eventid;
      int keywordid;

      // add an alert
      eventid = sqlstmts.addEvents(req, uid,
                         Location.NO_LOCATION_ID, Sponsor.NO_SPONSOR_ID);
  
      // retrieve keywordid
      String qry_statement = "select " 
                             + Fields.KKEYWORD_ID.getSelectName() 
                             + " from "
                             + Tables.KEYWORDS.getName() + " where " 
                             + Fields.KWORD.getStmtName() 
                             + "=\'Alerts\' and " 
                             + Fields.KCREATOR.getStmtName() + "=\'"
                             + DBResources.adminKeywordCreator() + "\'";
      ResultSet rs = sqlstmts.executeQuery(qry_statement);
  
      if (rs.next()) {
        keywordid = rs.getInt(Fields.KKEYWORD_ID.getName());
      } else {
        throw new SQLException(
            "retrieving keywordid failed (no record returned)!");
      }
  
      // create an event_keywords entry
      rs = sqlstmts.selectEventKeywords(eventid, keywordid);

      if (!rs.next()) {   // doesn't exist
        sqlstmts.addEventKeywords(eventid, keywordid);
      }
  
      // create a red *alert* entry if red alert is checked.
      if (pep.getRedAlert()) {
        rs = sqlstmts.executeQuery("select * from "
                                   + Tables.REDALERTS.getName() + " where " 
                                   + Fields.REVENT_ID.getStmtName() 
                                   + "=" + eventid);
        if (!rs.next()) {   // doesn't exist
          sqlstmts.executeUpdate(UpdtAlerts.addRedalert(eventid));
        }
      }
    } finally {
      sqlstmts.close();
    }

    //
    // read template and print alert added message.
    //
    new PrintWebPage(PEDefaults.ALERT_ADDED, out);
    out.close();
  }
}
