package pubevents.authtable;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.db.Fields;
// import edu.washington.cac.calendar.db.Tables;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

import uwcal.out.Page;

/** Check userid, and add it to authorization table if no error. 
  
  @author Leman Chung
  @version 2.0
 */
public class DeleteUsersEdit extends AdminServlet 
{

  public void performAction(HttpServletRequest req, HttpServletResponse res)
                 throws IOException
  {
    int userid = 0;
    ResultSet rs = null;
    String templateFile = PEDefaults.DELETE_USERS;
    SqlStatements sqlstmts;

    PEParameter pep = new PEParameter(req);
    PrintWriter out = res.getWriter();
    int counter = 0;
    String error_msg = "";

    String html_title = "Events Calendar: Delete A User from Authorization Table.";

    if (pep.getUserid() == null) {
        error_msg = "Missing User's NetID!";
    } else if (pep.getUserid().length() > 8) {
        error_msg = "User's NetID can not be longer than 8 characters!";
    } else if (pep.getUserid().indexOf(" ") != -1) {
        error_msg = "Found space inside user's NetID!";
    } else if (pep.getUserid().indexOf(",") != -1) {
        error_msg = "Found comma inside user's NetID!";
    }

    if (error_msg == "") {
        sqlstmts = new SqlStatements();
        try {
             rs = sqlstmts.selectUsers(pep.getUserid());
             if (rs.next()) {
                  // existed, and then retrieve userid.
                userid = rs.getInt(Fields.UUSER_ID.getName());
             } else {
                  // not exist, maybe deleted already.
                 error_msg = "User " + pep.getUserid()
                           + " is not existed in authorization table. "
                           + "It may be deleted already or you entered a "
                           + "wrong id!";
             }
             rs.close();
          if (error_msg == "") {
             rs = sqlstmts.selectAuth(userid);
             if (!rs.next()) {
                 error_msg = "User " + pep.getUserid()
                           + " is not existed in authorization table. "
                           + "It may be deleted already or you entered a "
                           + "wrong id!";
             }
          }
        } catch (SQLException e) {
            e.printStackTrace(System.err);
            System.err.println("SQL Exception: " + e.getMessage());
            error_msg = "ERROR: " + e.getMessage();
        } catch (Exception e) {
            e.printStackTrace(System.err);
            System.err.println("Exception: " + e.getMessage());
            error_msg = "ERROR: " + e.getMessage();
        } finally {
          sqlstmts.close();
        }
    }

    if (error_msg != "") {
        String field;
          // read and print out new Form
        BufferedReader in = new BufferedReader(new InputStreamReader(
                this.getClass().getResourceAsStream(templateFile)));

        String aline = in.readLine(); // IOException
        while (aline != null) {
          if (aline.startsWith("%%%html_title")) {
              out.println(html_title);
          } else if (aline.startsWith("%%%logo")) {
              out.println(Page.LOGO);
          } else if (aline.startsWith("%%%error_msg")) {
              new PrintErrorMessage().printError(out, error_msg);
          } else if (aline.startsWith("%%%" + PEParameter.USERID)) {
	    if (pep.getUserid() == null) {
	      out.println("");
	    } else {
              out.println("\"" + pep.getUserid() + "\"");
	    }
          } else if (aline.startsWith("%%%")) {
              // skip this line
          } else {
              out.println(aline);
          }
          aline = in.readLine();
        }
        in.close();
    } else {
            // delete this user from authorization table.
        try {
             new DeleteUsersDelete(res, userid);
        } catch (SQLException e ) {
             e.printStackTrace(System.err);
             System.err.println(e.toString());
             new PrintErrorMessage().printError(out, "ERROR: " + e.toString());
        }
    } 
    out.close();
  }
}
