package pubevents.extractdata;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.db.DBResources;
import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.PubEventsQueries;
import edu.washington.cac.calendar.db.Tables;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

import uwcal.out.Page;

/** Edit date range and then pull out records from
    database and then display it on user's terminal for
    user to save as text file if no error.  It will also
    mark the selected events for not been extracted again.
  
  @author Leman Chung
  @version 2.3
 */
public class ExtractDataEdit extends AdminServlet 
{
  public void performAction(HttpServletRequest req, HttpServletResponse res)
      throws IOException 
  {
    String smon, sday, syear,
                 emon, eday, eyear;
    String startRange = null, endRange = null;
    String qry_statement;
    ResultSet rs = null;
    SqlStatements sqlstmts;

    String templateFile = PEDefaults.DATE_RANGE;

    PEParameter pep = new PEParameter(req);
    PrintWriter out = res.getWriter();
    int counter = 0;

    String error_msg = "";
    String html_title = "Events Calendar: Extract data for University Week.";

      if (req.getParameter("smonth").trim().equals("None")) {
        error_msg = "Start month is not selected!";
      } else if (req.getParameter("emonth").trim().equals("None")) {
        error_msg = "End month is not selected!";
      }

      sqlstmts = new SqlStatements();
 
      // convert start/end  month/day/year to year-mm-dd format
      startRange = pep.getStartYear() + "-" + 
                   sqlstmts.monthNumber(pep.getStartMonth()) + "-" + 
                   pep.getStartDay();
      endRange = pep.getEndYear() + "-" + 
                 sqlstmts.monthNumber(pep.getEndMonth()) + "-" + 
                 pep.getEndDay();
   
      if (error_msg == "") {
        if (pep.getSubmit().startsWith("Extract only")) {
          qry_statement = SELECT + FROM + FROM2 +
                          WHERE1 + startRange + WHERE2 + endRange + WHERE3 + 
                          JOINS + JOINS2 + WHERE_NOT_MARKED + ORDER_BY;
        } else {
          qry_statement = SELECT + FROM + FROM2 + 
                          WHERE1 + startRange + WHERE2 + endRange + WHERE3 + 
                          JOINS + JOINS2 + ORDER_BY;
        }

        try {
          rs = sqlstmts.executeQuery(qry_statement);
        } catch (Exception e) {
          e.printStackTrace(System.err);
          System.err.println("Exception: " + e.getMessage());
          error_msg = "ERROR: " + e.getMessage();
        }
  
        try {
          if (error_msg == "") {
            out.println("<br><br>");
            out.println("&nbsp;&nbsp;&nbsp;events selected from " + startRange 
                        + " -- " + endRange);
            out.println("<br>");
            out.println("&nbsp;&nbsp;&nbsp;-------------------------------------------------");
  
            while (rs.next()) {
              UWeekEventPrinter ep = new UWeekEventPrinter(out, rs);

              out.println("<br><br>");
              ep.printStartdate();
              ep.printCategory();
              ep.printSponsor();
              ep.printShortdesc();
                // ep.printSpeakers();
              ep.printTime();
              ep.printLocation();
              ep.printCost();
              ep.printSponsorPhone();
              ep.printLongdesc();
            }  // end of while rs.next().
  
            markEvents(startRange, endRange);
          }
        } catch (Exception e) {
          e.printStackTrace(System.err);
          System.err.println("Exception: " + e.getMessage());
          error_msg = "ERROR: " + e.getMessage();
        }
      }
    sqlstmts.close();

    if (error_msg != "") {
      smon = pep.getStartMonth().substring(0, 3);
      sday = pep.getStartDay();
      syear = pep.getStartYear();
      emon = pep.getEndMonth().substring(0, 3);
      eday = pep.getEndDay();
      eyear = pep.getEndYear();

      // print out error_msg
      BufferedReader in = new BufferedReader(new InputStreamReader(
              this.getClass().getResourceAsStream(templateFile)));

      String aline = in.readLine(); // IOException

      while (aline != null) {
        if (aline.startsWith("%%%html_title")) {
          out.println(html_title);
        } else if (aline.startsWith("%%%logo")) {
              out.println(Page.LOGO);
        } else if (aline.startsWith("%%%error_msg")) {
          new PrintErrorMessage().printError(out, error_msg);
        } else if (aline.startsWith("%%%sel_smon")) {
          if (aline.indexOf(smon) != -1) {
            out.println("selected");
          }
        } else if (aline.startsWith("%%%sel_sday")) {
          if (aline.indexOf(sday) != -1) {
            out.println("selected");
          }
        } else if (aline.startsWith("%%%sel_syear")) {
          if (aline.indexOf(syear) != -1) {
            out.println("selected");
          }
        } else if (aline.startsWith("%%%sel_emon")) {
          if (aline.indexOf(emon) != -1) {
            out.println("selected");
          }
        } else if (aline.startsWith("%%%sel_eday")) {
          if (aline.indexOf(eday) != -1) {
            out.println("selected");
          }
        } else if (aline.startsWith("%%%sel_eyear")) {
          if (aline.indexOf(eyear) != -1) {
            out.println("selected");
          }
        } else if (aline.startsWith("%%%")) {
          // skip this line
        } else {
          out.println(aline);
        }
        aline = in.readLine();
      }
      in.close();
    }
    out.close();
  }

  /** Start of the select query */
  private static final String SELECT =
      "select " 
      + Fields.EEVENT_ID.getSelectName() + ", " 
      + Fields.ESTARTDATE.getSelectName() + ", " 
      + Fields.EENDDATE.getSelectName() + ", "
      + Fields.ESHORTDESC.getSelectName() + ", "
      + Fields.ELONGDESC.getSelectName() + ", "
      + Fields.ELONGDESC1.getSelectName() + ", " 
      + Fields.ESTARTTIME.getSelectName() + ", "
      + Fields.EENDTIME.getSelectName() + ", "
      + Fields.ECOST.getSelectName() + ", " 
      + Fields.KWORD.getSelectName() + ", " 
      + Fields.SNAME.getSelectName() + ", " 
      + Fields.SPHONE.getSelectName() + ", " 
      + Fields.LADDRESS.getSelectName();
      
  private static final String FROM =
      " from "
      + Tables.EVENTS.getName() + ", "
      + Tables.EVENTKEYWORDS.getName() + ", "
      + Tables.KEYWORDS.getName();
     
  private static final String FROM2 = ", "
      + Tables.SPONSORS.getName() + ", "
      + Tables.LOCATIONS.getName();
      
  /** First part of the where clause */
  /* Don't use PubEventsQueries.baseStandardWhere, as it selects both
     official and unofficial events, and we only want official events
   */
  private static final String WHERE1 = 
      " where " 
      + Fields.KCREATOR.getStmtName() 
      + "=\'" + DBResources.officialKeywordCreator() + "\' and " 
      + Fields.EPUBLIC.getStmtName() + "=\'T\' and " 
      + Fields.ESTARTDATE.getStmtName() + " >= \'";

  /** Second part of the where clause */
  private static final String WHERE2 = "\' and " + 
                                        Fields.ESTARTDATE.getStmtName() + 
                                        " <= \'";

  /** Third part of the where clause */
  private static final String WHERE3 = 
      "\'";
      
  /** Join clauses used in all db statements */
  private static final String JOINS = 
      " and "
      + Fields.EEVENT_ID.getStmtName() + "=" 
      + Fields.EKEVENT_ID.getStmtName() + " and "
      + Fields.EKKEYWORD_ID.getStmtName() + "="
      + Fields.KKEYWORD_ID.getStmtName();

  /** Join clauses used in select queries only */
  private static final String JOINS2 = 
      " and "
      + Fields.ESPONSOR_ID.getStmtName() + "="
      + Fields.SSPONSOR_ID.getStmtName() + " and "
      + Fields.ELOCATION_ID.getStmtName() + "="
      + Fields.LLOCATION_ID.getStmtName();

  /** Optional part of the where clause to exclude marked events */
  private static final String WHERE_NOT_MARKED = 
      " and " 
      + Fields.EEVENT_ID.getStmtName() 
      + " not in (select " 
                  + Fields.MEVENT_ID.getSelectName()                                              + " from "
                  + Tables.MARKEDEVENTS.getName() 
      + ")";
      
  /** Order by clause */
  private static final String ORDER_BY = 
      " order by " 
      + Fields.ESTARTDATE.getStmtName() + ", " 
      + Fields.KWORD.getStmtName() + ", "
      + Fields.ESTARTTIME.getStmtName() + ", "
      + Fields.EENDTIME.getStmtName();

  /** Get SQL to mark events
    @param startRange first date in the range to mark
    @param endRange last date in the range to mark
    @return SQL to mark events in the range
   */
  private static String markEventsSQL(String startRange, String endRange)
  {
    return "insert into " + Tables.MARKEDEVENTS + "(" +
          Fields.MEVENT_ID.getInsertName() + ") select " +
          Fields.EEVENT_ID.getSelectName() + FROM + WHERE1 + startRange +
          WHERE2 + endRange + WHERE3 + JOINS + WHERE_NOT_MARKED;
  }

  /** Mark events in the range as extracted 
    @param startRange First date in the range
    @param endRange Last date in the range
    @exception SQLException if there's a problem
   */
  private void markEvents(String startRange, String endRange)
      throws SQLException 
  {
    SqlStatements sqlstmts = new SqlStatements();

    try {
      sqlstmts.executeUpdate(markEventsSQL(startRange, endRange));
    } finally {
      sqlstmts.close();
    }
  }

  /**
    print the SQL used to standard output
    @param args ignored
   */
  public static void main(String[] args)
  {
    System.out.println(markEventsSQL("START", "END"));
  }
}
