package pubevents.extractdata;

import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.Calendar;

import org.apache.ecs.StringElement;
import org.apache.ecs.html.BR;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.db.Fields;
import uwcal.out.DisplayText;
import uwcal.out.forms.FormsDisplayText;

/** Prints an event

  * Modified from EventPrinter specifically for Uweek only.
  * The difference are no field tag and no field break for many fields
  * and separated by comma. 
  
  @author Leman Chung
  @version 1.0
 */
public class UWeekEventPrinter extends EventPrinter
{
  /** Create a new UWeekEventPrinter
    @param out Writer to print to 
    @param rs Result set, currently pointing to the event to print 
   */
  UWeekEventPrinter(PrintWriter out, ResultSet rs)
  {
    super(out, rs);
  }

  /** field separator. */
  public static final String FS = ", ";

  /** Print the starting date of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printStartdate() throws SQLException
  {
    MyCalendar cal = 
        new MyCalendar(this.rs.getDate(Fields.ESTARTDATE.getName()));
    this.out.print(cal.timeString(new SimpleDateFormat(
        "EEEE, '" + AP_MONTH[cal.get(Calendar.MONTH)] + "' d")));
    this.out.println(BR);
  }

  /** Print the (1st) category of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printCategory() throws SQLException
  {
    this.out.print(this.rs.getString(Fields.KWORD.getName()).
                         replace('_', ' '));
    this.out.println(BR);
  }

  /** Print the short description of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printShortdesc() throws SQLException
  {
    this.out.print(this.rs.getString(Fields.ESHORTDESC.getName()));
    this.out.print(FS);
  }

  /** Print the long description of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printLongdesc() throws SQLException
  {
    this.out.print(Fields.getEventLongdesc(this.rs));
  }


  /** Print the time of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printTime() throws SQLException
  {
    if (this.rs.getTime(Fields.ESTARTTIME.getName()) == null
        && this.rs.getTime(Fields.EENDTIME.getName()) == null) 
    {
      return;
    }


    MyCalendar startCal =
        new MyCalendar(this.rs.getDate(Fields.ESTARTDATE.getName()),
                       this.rs.getTime(Fields.ESTARTTIME.getName()));

    if (this.rs.getTime(Fields.EENDTIME.getName()) != null) 
    {
      MyCalendar endCal =
          new MyCalendar(this.rs.getDate(Fields.EENDDATE.getName()),
                         this.rs.getTime(Fields.EENDTIME.getName()));
      this.out.print(time(startCal, 
          startCal.get(Calendar.AM_PM) != endCal.get(Calendar.AM_PM)
          || endCal.get(Calendar.HOUR) % 12 ==  0));
      this.out.print("-");
      this.out.print(time(endCal, true));
    } else {
      this.out.print(time(startCal, true));
    }

    this.out.println(FS);
  }

  /** Print the location of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printLocation() throws SQLException
  {
    if (this.rs.getString(Fields.LADDRESS.getName()) != null &&
        !this.rs.getString(Fields.LADDRESS.getName()).
            equalsIgnoreCase(DisplayText.NO_VALUE))
    {
      this.out.print(this.rs.getString(Fields.LADDRESS.getName()));
      this.out.println(FS);
    }
  }


  /** Print the cost of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printCost() throws SQLException
  {
    if (this.rs.getString(Fields.ECOST.getName()) != null &&
        !this.rs.getString(Fields.ECOST.getName()).equals(""))
    {
      this.out.print(this.rs.getString(Fields.ECOST.getName()));
      this.out.println(FS);
    }
  }

  /** Print the sponsor of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printSponsor() throws SQLException
  {
    if (rs.getString(Fields.SNAME.getName()) != null &&
        !rs.getString(Fields.SNAME.getName()).
            equalsIgnoreCase(DisplayText.NO_VALUE))
    {
      this.out.print(this.rs.getString(Fields.SNAME.getName()));
      this.out.println(FS);
    }
  }

  /** Print the phone number of the sponsor of the event
    @exception SQLException if there's trouble getting the data from the 
      result set
   */
  public void printSponsorPhone() throws SQLException
  {
    if (rs.getString(Fields.SPHONE.getName()) != null &&
        !rs.getString(Fields.SPHONE.getName()).equals(""))
    {
      this.out.print(rs.getString(Fields.SPHONE.getName()));
      this.out.println(FS);
    }
  }

}
