package pubevents.updtevents;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.data.User;
import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.Tables;
import edu.washington.cac.calendar.db.PubEventsQueries;

import pubevents.NotAdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** list events to select for update.
  
  @author Leman Chung
  @version 2.0
 */
public class ListUpdates extends NotAdminServlet
{
  PrintWriter out;

  private String templateFile = PEDefaults.UPDATE_EVENTS;
  private String templateFooter = PEDefaults.FOOTER;
  private String templateBackToMenu = PEDefaults.BACK_TO_MENU;

  public void performAction(HttpServletRequest req, HttpServletResponse res)
      throws IOException 
  {
    ResultSet rs = null;
    out = res.getWriter();
    SqlStatements sqlstmts = new SqlStatements ();

    try {
      rs = sqlstmts.executeQuery(new PubEventsQueries().
          listUpdatesQuery(new User(getUid())).toString());
    } catch (Exception e) {
      e.printStackTrace(System.err);
      System.err.println(e.getMessage());
      new PrintErrorMessage().printErrorAndClose(out, 
                                                 "ERROR: " + e.getMessage(), 
                                                 templateBackToMenu);
      return;
    }

    try {
      if (!rs.next()) {
        // print out no event to update error message.
        new PrintWebPage(PEDefaults.LOGOHEADER, out);
        out.println("<br><br><b>No events created by user " + getUid() + " existed!</b>");
        new PrintWebPage(templateBackToMenu, out);
        out.close();
        return;
      } else {
        new PrintWebPage(templateFile, out); // print out header

        do {
           // print out start-end dates, title and description.
          out.println("<tr><td><input type=\"radio\" name=\"" + 
                      PEParameter.EVENT_ID + "\" value=\"" + 
                      rs.getString(Fields.EEVENT_ID.getName()) + "\"></td>");
          out.println("<td>" + rs.getDate(Fields.ESTARTDATE.getName()) + 
                      "</td>");
          out.println("<td>" + rs.getDate(Fields.EENDDATE.getName()) + "</td>");
          out.println("<td>" + rs.getString(Fields.ESHORTDESC.getName()) + 
                      "</td>");
          out.print("<td>" + Fields.getEventLongdesc(rs));
          out.println("</td></tr>");
        } while (rs.next());

        out.println("<tr><td></td><td></td><td></td><td></td></tr>");
        out.println("<tr><td></td><td></td>");
        out.println("<td><input type=\"submit\" value=\"Submit\"></td>");
        out.println("<td><input type=\"reset\" value=\"Clear\"></td>");
        out.println("<td></td></tr>");
      }
    } catch (Exception e) {
      e.printStackTrace(System.err);
      System.err.println(e.getMessage());
      new PrintErrorMessage().printErrorAndClose(out, 
                                                 "ERROR: " + e.getMessage(), 
                                                 templateBackToMenu);
      return;
    } finally {
      sqlstmts.close();
    }

    out.println("</TABLE>\n</FORM>");
    new PrintWebPage(templateFooter, out);
    out.close();
  }
}
