// java

package uwcal;

import java.io.IOException;
import java.sql.SQLException;

import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.CaldataException;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.ItemException;
import edu.washington.cac.calendar.data.NoSuchItemException;
import edu.washington.cac.calendar.data.User;
import edu.washington.cac.myuw.servlet.Log;

import uwcal.out.Page;

/**
  An action (function) in the application that display a page
  @author Greg Barnes
  @version 1.2
 */
public class PageAction extends CalAction 
{
  /**
    Create a minimal PageAction, not suitable for performing actions.
    This object can be used to match function names with the proper 
    PageAction class, and calling newInstance to create a more complete 
    version of the object which can perform the action

    @param function Name of the function this PageAction can handle
   */
  PageAction(String function) {
    super(function);
  }

  /** Create a new PageAction to perform actions

    @param function The function that was called
    @param cal The day for the action
    @param user The user performing the action
    @param es The EventsI object for the user
    @param cp The form parameters
    @param log A file to print messages to
   */
  protected PageAction(String function,         
                      MyCalendar cal, 
                      User user, 
                      EventsI es,
                      CalParameter cp,
                      Log log) 
  {
    super(function, cal, user, es, cp, log);
  }

  /** @return a new PageAction
    @param cal The date in question
    @param user The user performing the action
    @param es The events for the user
    @param cp Form parameters
    @param log A file to print messages to
   */   
  CalAction newInstance(MyCalendar cal, 
                        User user, 
                        EventsI es, 
                        CalParameter cp,
                        Log log) 
  {
    return new PageAction(getHandlesFunction(), cal, user, es, cp, log);
  }

  /** Do nothing
   */
  protected void basePerformAction() {}        // no action to perform

  /**
    Print the page to the servlet's output stream
    @param resp The servlet's response object
    @exception IOException if there's a problem printing the page
    @exception ItemException if there's something wrong with the item chosen
    @exception SQLException if there's a problem with the database
    @exception CaldataException if the database contains bad data
   */
  protected void baseGeneratePage(HttpServletResponse resp) 
    throws IOException, ItemException, SQLException,
           CaldataException
  {
    Page.create(getHandlesFunction(), cal, this.user, es, message, 
                cp).print(resp);
  }
}
