// java

package uwcal;

import java.io.IOException;
import java.util.Locale;
import java.util.TimeZone;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.myuw.servlet.ServletSupport;
import edu.washington.cac.myuw.servlet.session.InvalidSession;
import edu.washington.cac.myuw.servlet.session.UWSession;
import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.CalProperties;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.PersonalEvents;
import edu.washington.cac.calendar.data.User;
import edu.washington.cac.calendar.db.Caldata;

import uwcal.out.DisplayText;
import uwcal.out.Page;
import uwcal.out.WebResources;

public class UWCal extends CalServlet 
{
  private static final String NAME = "UWCal";

  public void init(ServletConfig conf) throws ServletException 
  {
    super.init(conf);
    createLog().println("Starting " + NAME + " servlet......");
    Locale.setDefault(Locale.US);
    TimeZone.setDefault(TimeZone.getTimeZone("PST"));
  }

  public void doGet(HttpServletRequest req, HttpServletResponse resp)
      throws ServletException, IOException
  {
    doPost(req, resp);
  }

  /**
    Handle an HTTP POST request
    @param req The HTTP request object
    @param resp The HTTP response object
    @exception ServletException if there's a problem on the servlet end
    @exception IOException if there's a problem writing the response
   */
  public void doPost(HttpServletRequest req, HttpServletResponse resp)
      throws ServletException, IOException
  {
    /* cheap fix to prevent correct browsers from reusing pages.
       Note:  Do not want to use 'no-cache' pragma, as we do
       want to allow browsers to return old pages via history
       mechanisms or the back button.  Setting an expiration date,
       however, should force 'forward' requests to query the server.
     */
    //%%%% this should be changed to a simple 'last-modified' scheme
//        resp.setHeader("Expires","Thu, 01-Jan-1970 00:00:01 GMT");

    CalServletSupport ss = new CalServletSupport(NAME);
  
    try {
      CalSession session = new CalSession(req);
      ss.setLog(session.getLog());

      /** security check */
      if (!session.matchedIdentifier()) {
	session.getLog().println(getReferer(req) + 
                                 " for " + req.getQueryString() + 
                                 " has unmatched identifier!");
        throw new IllegalStateException("unmatched identifier");
      }

      String uid = session.verify();

      if (CalProperties.defaultIsGuest() && !uid.equals(CalSession.GUESTID)) {
        /* can happen if bouncing between pub events entry and pub events 
           display */
        throw new InvalidSession(DisplayText.MUST_RELOGIN);
      }

      if (session.getUser() == null) {
        throw new IllegalStateException("no user!");
      }
  
      if (session.getUser().getNameDB() != uid) {
        throw new IllegalStateException("uid " + uid + 
                                        " does not match User's name " + 
                                        session.getUser().getNameDB());
      }

      if (!session.getUser().isGuest()) {
        if (!isHttps(req) && CalProperties.useHttps()) {
          sendRedirect(req, resp, 
              WebResources.BASE_NOPARAM_URL + req.getQueryString(), true);
          return;
        }
      }

      EventsI es = session.getCalProfile().getEvents();
      CalAction ca = CalActionHandler.create(req, session.getUser(), es, 
                                             session.getLog());
      ss.setId(NAME + ":" + ca.getHandlesFunction());
      ca.performAction();
      ca.generatePage(resp);

      // for greater efficiency, could store these only when they are 'changed'
      session.getCalProfile().storeEvents(es);
    } catch (Throwable e){
      ss.handleException(e, req, resp);
    } finally {
      ss.done();
    }
  }

  /** Test the servlet by printing today's page for a user 
    @param args Ignored
    @exception Exception if there's a problem
   */
  public static void main (String args[]) throws Exception 
  {
    MyCalendar cal = new MyCalendar();
    Page.create(CalParameter.DAYVIEW_FUNC, cal, new User("gsbarnes"), 
        new PersonalEvents(new User("gsbarnes")), null, null).print();
  }
}
