// java

package uwcal.out;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.util.Properties;

import org.apache.ecs.AlignType;
import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.Entities;
import org.apache.ecs.html.Address;
import org.apache.ecs.html.BR;
import org.apache.ecs.html.Comment;
import org.apache.ecs.html.HR;
import org.apache.ecs.html.IMG;
import org.apache.ecs.html.Table;
import org.apache.ecs.html.TD;
import org.apache.ecs.html.TR;

import edu.washington.cac.calendar.CalProperties;
import edu.washington.cac.calendar.CalLogFactory;
import edu.washington.cac.myuw.util.Coder;

import uwcal.CalProfile;

/**
  Text that the user sees.
  Should be localized/internationalized.  That is, it should be a 
  ResourceBundle.

  For now, most text is constants in the file, but things are slowly being
  moved to text.properties.

  @author Greg Barnes
  @version 2.1
 */
public class DisplayText 
{
  /** Location of the properties file */
  private static final String PROPERTIES_FILE =
      "/properties/calendar/text.properties";

  /** Object to hold properties */
  private static Properties properties = new Properties();

  /** Load properties file */
  static {
    try {
      properties.load(WebResources.class.getResourceAsStream(PROPERTIES_FILE));
    } catch(Exception e) {
      e.printStackTrace(new CalLogFactory().create().getPrintStream());
      new CalLogFactory().create().
          println("Cannot find " + PROPERTIES_FILE);
    }
  }

  /** @return the name of the file that holds the page footer */
  public static String footerFile() 
  {
    return properties.getProperty("footerFile");
  }

  /** What we call an event */
  public static final String EVENT = 
    CalProperties.defaultIsGuest() ? "Event" : "Entry";

  /** What we call more than one event */
  public static final String EVENTS = 
    CalProperties.defaultIsGuest() ? "Events" : "Entries";

  /** A more verbose way to call more than one events */
  public static final String LONG_EVENTS = 
    CalProperties.defaultIsGuest() ? "Public Events" : "Calendar Entries";

  /** What we call a location */
  public static final String LOCATION = "Location";

  /** What we call a sponsor */
  public static final String SPONSOR = "Sponsor";

  /** What we call a keyword */
  public static final String KEYWORD = "Keyword";

  /** What we call a subscription */
  public static final String SUBSCRIPTION = "Subscription";

  /** What the user sees if there are no events for some 
      indeterminate length of time 
   */
  static final String NO_EVENTS = "No " + EVENTS.toLowerCase();

  /** What the user sees if there are no events for a particular day */
  static final String NO_EVENTS_TODAY = NO_EVENTS + " for this day";

  /** Name of this application */
  public static final String APP_NAME = "UW Calendar";

  static final String ABOUT_TEXT = "About " + APP_NAME;
  static final String HELP_TEXT = "Help";
  static final String PREFERENCES = "Preferences";
  static final String LOGGED_IN_TEXT = "Logged in as: ";
  static final String NOT_LOGGED_IN = "Not logged in";

  static final String LOGIN_AGAIN = "log in again.";

    // <title> elements for the pages
  static final String DAYVIEW_TITLE = APP_NAME + " day view";
  static final String WEEKVIEW_TITLE = APP_NAME + " week view";
  static final String MONTHVIEW_TITLE = APP_NAME + " month view";
  static final String YEARVIEW_TITLE = APP_NAME + " year view";
  static final String EDIT_TITLE = "Edit " + APP_NAME + " " + EVENT;
  static final String EVENT_TITLE = "Display " + APP_NAME + " " + EVENT;
  static final String ADD_KEYWORD_TITLE = "Add " + APP_NAME + " " + KEYWORD;
  static final String EDIT_KEYWORD_TITLE = "Edit " + APP_NAME + " " + KEYWORD;
  static final String ADD_SPONSOR_TITLE = "Add " + APP_NAME + " " + SPONSOR;
  static final String EDIT_SPONSOR_TITLE = "Edit " + APP_NAME + " " + SPONSOR;
  static final String ADD_LOCATION_TITLE = "Add " + APP_NAME + " " + LOCATION;
  static final String EDIT_LOCATION_TITLE = 
    "Edit " + APP_NAME + " " + LOCATION;

  /** Title of the 'all calendars' page */
  static final String ALLCALENDARS_TITLE = APP_NAME + ": List of All Calendars";

  /** Title of the subscriptions page */
  static final String SUBSCRIPTIONS_TITLE = APP_NAME + ": Subscriptions";

    // text displayed in the body for various entities

  static final String EVENTVIEW_HEADER = "Display " + EVENT;

  /** text displayed at the top of the 'all calendars' page */
  static final String ALLCALENDARS_HEADER = "Complete List of Calendars";

  /** Start of the header for the list of a day's events */
  static final String DAY_EVENTS_HEADER = LONG_EVENTS + " for ";

  /** Many NBSP entities */
  static final String MANY_NBSP = 
      Entities.NBSP + Entities.NBSP + Entities.NBSP;

  /** Get text that appears in a navButton
    @param name Name of the button
    @return text that appears in a navButton
   */
  private static String navButtonString(String name) 
  {
    return MANY_NBSP + name + MANY_NBSP;
  }

  static final String TODAY = navButtonString("Today");
  static final String DAYVIEW = navButtonString("Day");
  static final String WEEKVIEW = navButtonString("Week");
  static final String MONTHVIEW = navButtonString("Month");
  static final String YEARVIEW = navButtonString("Year");

  static final String LOGO_ALT = APP_NAME + " Logo";

  /** Text that links to the Add Locations page */
  static final String ADD_LOCATION_TEXT = "Add Location";
  
  /** Text that links to the Subscriptions page */
  static final String SUBSCRIPTIONS_TEXT = "Subscriptions";
  
  /** The anchor text for the link to submit a public event */
  static final String SUBMIT_PUBLIC_EVENT_TEXT = "Submit Public Event";

  /** Text for the 'more' link */
  static final String MORE = "More";

  /** Text for the 'edit' link */
  public static final String EDIT = "Edit";

  /** Text for the 'delete' link */
  static final String DELETE = "Delete";

  /** Text for the 'remove' link */
  static final String REMOVE = "Remove";

  /** Text for the 'remove all' link */
  static final String REMOVE_ALL = REMOVE + " All";

  /** Text for the 'subscribe' link */
  static final String SUBSCRIBE = "Subscribe";

  /** Text for the 'unsubscribe' link */
  static final String UNSUBSCRIBE = "Unsubscribe";

  static final String WEEK_OF = "Week of ";
  static final String WEEK_ABBR = "wk";

  public static final String NO_VALUE = "None";
  public static final String NEXT = "Next";
  public static final String PREVIOUS = "Previous";
  public static final String SEPARATOR = "|";

  public static final String PUBLIC_STRING = "Public";
  static final String PRIVATE_STRING = "Private";
  static final String CREATED = "created by";
  static final String COST = "Cost: ";

  /** Official email address */
  static final String OFFICIAL_EMAIL = "newsweb@u.washington.edu";

  /** URL for official email address */
  static final String OFFICIAL_URL = "mailto:" + OFFICIAL_EMAIL;

  /** Contact text for an official public event */
  static final String OFFICIAL_CONTACT = 
      "For corrections to this " + EVENT.toLowerCase() + ", contact " +
      Util.linkItem(OFFICIAL_URL, OFFICIAL_EMAIL).toString() + ".";

  static final String LOCATIONF = LOCATION + ": ";
  static final String SPONSORF = SPONSOR + ": ";
  public static final String PHONE = "Phone";
  static final String PHONEF = PHONE + ": ";
  public static final String EMAIL = "E-mail";
  static final String EMAILF = EMAIL + ": ";
  public static final String KEYWORDS = KEYWORD + "s";
  static final String KEYWORDSF = KEYWORDS + ": ";

  /** Text that identifies an event as recurring */
  public static final String RECURRING_EVENT = "Recurring event";

  /** Start of a list of other instances of a recurring event */
  public static final String RECURLIST_START = 
      "Other known instances of this event: ";

  static String publicPrivate(boolean isPublic, String x) 
  {
      return (isPublic ? PUBLIC_STRING : PRIVATE_STRING) + " " + x;
  }

  static final Element COPYRIGHT = new Comment("Copyright (c) 1999-2000 UW");

  /** The e-mail address to contact for questions/comments */
  static final String CONTACT_EMAIL = "uwchelp@cac.washington.edu";

/*
  private static final String UW_HOME = "http://www.washington.edu";
  private static final String UWIMG_URL = "/graphics/uwid.gif";
  private static final String UWIMG_ALT = "to UW home";

  private static final Element uwImg() {
      return Util.linkItem(UW_HOME, 
        new IMG(UWIMG_URL).setWidth(94).setHeight(33).setAlt(UWIMG_ALT).
          setAlign(AlignType.BOTTOM).setBorder(0).setHspace(5),
        null, null);
  }

  private static final String ADDRESS1 = "Computing & Communications";

  private static final Element ADDRESS = new ElementContainer().
    addElement(ADDRESS1).addElement(new BR()).addElement("\n").
    addElement(CONTACT_EMAIL).addElement(new BR());

  private static final Element addressRow() {
      TR tr = new TR();
      tr.addElement(new TD().setAlign(AlignType.CENTER).
        setWidth("15%").addElement(uwImg())).addElement("\n");
      return tr.addElement(new TD().setVAlign(AlignType.TOP).
        addElement(new Address().addElement(ADDRESS)));
  }

  private static final Element uwFooter() {
      ElementContainer ec = new ElementContainer();
      ec.addElement(new HR().setSize(2).setNoShade(true).
        setAlign(AlignType.LEFT)).addElement("\n");
      return ec.addElement(new Table().setBorder(0).setWidth("100%").
        addElement(addressRow()));
  }
*/

  /** The page footer (read from a file) */
  static String footer = new String();

  /** Read in the page footer */
  static {
    try {
      BufferedReader in = new BufferedReader(new InputStreamReader(
          DisplayText.class.getResourceAsStream(footerFile())));
      String s = in.readLine();

      while (s != null) {
        footer += s + "\n";
        s = in.readLine();
      }
    } catch (IOException e) {
      e.printStackTrace();
      System.err.println("DisplayText: Couldn't initialize page footer");
    }
  }

  /** Text the user sees to indicate something was added */
  private static final String ADDED = "added";

  /** Text the user sees to indicate something was deleted */
  private static final String DELETED = "deleted";

  /** Text the user sees to indicate something was removed */
  private static final String REMOVED = "removed";

  /** Text the user sees to indicate something was changed */
  private static final String REPLACED = "updated";

  /**
    Create a general status message for db operations
    @param number Number of entities processed
    @param op Operation performed
    @param entity Type of entity processed.
    @return a corresponding status message
   */
  private static String msg(int number, String op, String entity) 
  {
    return number + " " + entity + " " + op + ".";
  }

  /**
    Create a general status message for db operations on one entity
    @param op Operation performed
    @param entity Type of entity processed.
    @return a corresponding status message
   */
  private static String msg(String op, String entity) 
  {
    return msg(1, op, entity);
  }

  /** Message to display after a calendar is successfully subscribed to */
  private static String SUBSCRIBE_MSG = msg(ADDED, SUBSCRIPTION);

  /** Message to display after a calendar is successfully unsubscribed from */
  private static String UNSUBSCRIBE_MSG = msg(DELETED, SUBSCRIPTION);

  private static String addMsg(String entity) 
  {
    return msg(ADDED, entity);
  }

  private static String deleteMsg(String entity) 
  {
    return msg(DELETED, entity);
  }

  /** 
    Get The message the user sees if something is removed
    @param entity Name of the entity removed 
    @return The message the user sees if something is removed
   */
  private static String removeMsg(String entity) 
  {
    return msg(REMOVED, entity);
  }

  /** 
    Get The message the user sees if all instances of something are removed
    @param entity Name of the entity removed 
    @return The message the user sees if all instances of something are removed
   */
  private static String removeAllMsg(String entity) 
  {
    return "All instances " + REMOVED;
  }

  private static String replaceMsg(String entity) 
  {
    return msg(REPLACED, entity);
  }

  /**
    Messages the user sees if a particular add or replace operation is 
    successful
   */
  public static String[] OP_MESSAGES = {
    addMsg(EVENT), replaceMsg(EVENT),
    addMsg(KEYWORD), replaceMsg(KEYWORD),
    addMsg(SPONSOR), replaceMsg(SPONSOR),
    addMsg(LOCATION), replaceMsg(LOCATION)
  };

  /**
    Messages the user sees if a particular delete operation is successful
   */
  public static String[] DELETE_OP_MESSAGES = {
    deleteMsg(EVENT), deleteMsg(KEYWORD), deleteMsg(SPONSOR), 
    deleteMsg(LOCATION)
  };

  /**
    Messages the user sees if a particular eventref operation is successful
   */
  public static String[] REF_OP_MESSAGES = {
    addMsg(EVENT), removeMsg(EVENT), removeAllMsg(EVENT), SUBSCRIBE_MSG,
    UNSUBSCRIBE_MSG
  };

  /** Get the message to display after the subscriptions form is submitted 
    @param results of the form, as a 3 entry array:  subscriptions, 
      unsubscriptions, and unknown calendars
    @return the message to display after the subscriptions form is submitted 
   */
  public static String subscribeMessage(int[] results)
  {
    String message = "";

    if (results[0] > 0) {
      message += msg(results[0], ADDED, 
                     SUBSCRIPTION + (results[0] == 1 ? "" : "s")) + "  ";
    }

    if (results[1] > 0) {
      message += msg(results[1], DELETED, 
                     SUBSCRIPTION + (results[1] == 1 ? "" : "s")) + "  ";
    }

    if (results[2] > 0) {
      message += msg(results[2], "ignored", "unknown calendars");
    }

    return message.length() > 0 ? message : "No subscriptions changed.";
  }

  public static final String ADDED_LOCATION_MSG = OP_MESSAGES[6];

  public static String genericErrorMessage(String operation) {
    return operation + " was not successful";
  }

  /** Message to give when they try to add something that's already there */
  public static final String DUPLICATE_ITEM = "Perhaps it already exists?";

  /** Message to give when they try to treat a subscribed item as a separate
      item */
  public static final String SUBSCRIPTION_ITEM = 
      "Subscribed items cannot be edited or deleted.";
  
  /** Message to give when they refer to something that doesn't exist*/
  public static final String NO_SUCH_ITEM = "No such item.";
  
  /** Generic DB error message */
  public static final String DB_ERROR = "Database error.";

  private static String oneMessage(String msg) 
  {
    if (msg == null) {
      return "";
    } else {
      return msg;
    }
  }

  /**
    Add two messages together.  We assume both messages have already
    been HTML encoded.
    @param msg1 First message
    @param msg2 Second message
    @return The two messages together.
   */
  public static String addMessage(String msg1, String msg2) 
  {
    if (msg1 == null) {
      return oneMessage(msg2);
    }

    if (msg2 == null) {
      return oneMessage(msg1);
    }

    return msg1 + Entities.NBSP + Entities.NBSP + msg2;
  }

  /** Alt text for addeventref icon */
  static final String ADD_TO_CALENDAR_ALT = "Add to my " + APP_NAME;

  /** Start of list of filters message */
  static final String FILTER_LIST_START = "Current filter: ";

  /** Start of calendar filter message */
  static final String CALENDAR_FILTER_START = "Current calendar: ";

  /** Legend for 'add this to my calendar' image */
  static final Element ADD_ICON_LEGEND = 
      Util.spanItem(" = " + ADD_TO_CALENDAR_ALT, Style.FOOTNOTE);

  /** Message displayed if you're bouncing between public events entry and
      display */
  public static final String MUST_RELOGIN = 
      "You must relogin to the public events calendar.";
}
