// java

package uwcal.out;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.ItemAccessException;
import edu.washington.cac.calendar.data.Keyword;
import edu.washington.cac.calendar.data.NoSuchItemException;
import edu.washington.cac.calendar.data.User;

import uwcal.out.forms.CalendarForm;
import uwcal.out.forms.EditKeywordForm;

/**
  Page to edit a keyword
  @author Greg Barnes
  @version 1.1
 */
public class EditKeyword extends EditEntity 
{
  /** Create a new instance
    @param es user's event cache
    @param message Message to print at top of the page
    @param view View to return to when we're done
    @param k Keyword to edit.  Should contain the correct id, but need not
      contain other fields

    @exception NoSuchItemException If an event with the matching id does
      not exist
    @exception ItemAccessException If the user cannot edit the event
   */
  EditKeyword(EventsI es, 
              String message, 
              Timeview view,
              Keyword k) 
      throws NoSuchItemException, ItemAccessException
  {
    super(es, message, view, DisplayText.EDIT_KEYWORD_TITLE, 
          es.getKeywords().getKeyword(k.getId()));
  }

  /**
    Get the form used by this page
    @return the form used by this page
   */
  protected CalendarForm getForm()
  {
    return new EditKeywordForm(this, (Keyword) this.c);
  }

  /** Return the URL for editing the keywords.
    @param mc Current date
    @param k keywords to edit.
    @param page Page the URL is a part of
    @param sid The session identifier
  */
  public static String url(MyCalendar mc, Keyword k, Page page, int sid) 
  {
    return EditEntity.url(CalParameter.EDITKEYWORD_FUNC, 
                          Util.KEYWORD_ID_PARAM, mc, page, k, sid);
  }
}
