// java

package uwcal.out;

import java.sql.SQLException;
import java.util.Calendar;

import org.apache.ecs.AlignType;
import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.html.TD;
import org.apache.ecs.html.TR;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.ItemException;

public abstract class Month 
{
  MyCalendar mc;
  EventsI es;
  GridPrinter gp;

  protected Month(MyCalendar mc, EventsI es, GridPrinter gp) {
      this.mc = mc;
      this.es = es;
      this.gp = gp;
  }

  protected abstract Element blankDay();

  protected TR emptyWeek(MyCalendar dayInWeek) {
      return new TR().setAlign(AlignType.RIGHT).addElement("\n");
  }

  private int numberOfInitialBlankDays() {
      return (mc.daysInWeek() + mc.dayOfWeekOfFirstDay() - 
        mc.getFirstDayOfWeek()) % mc.daysInWeek();    
  }

  private int numberOfFinalBlankDays() {
      return (mc.daysInWeek() + mc.getLastDayOfWeek() - 
        mc.dayOfWeekOfLastDay()) % mc.daysInWeek();    
  }

  private Element blankDays(int count) {
      ElementContainer ec = new ElementContainer();
      int i;

      for (i = 1; i <= count; i++) {
          ec.addElement(blankDay());
      }

      return ec;
  }

  /**
    print the main grid for the month
    @returns the grid as an HTML element
    @exception SQLException if the grid contains events, and there
      was a problem loading the events
    @exception ItemException if the grid contains events, and 
      the events had bad data
   */
  Element monthGrid() throws SQLException, ItemException
  {
    ElementContainer ec = new ElementContainer();

    MyCalendar currentDay = new MyCalendar(mc.firstDayOfThisMonth());
    TR tr = emptyWeek(currentDay);
    tr.addElement(blankDays(numberOfInitialBlankDays())).addElement("\n");

    int i, weekpos = mc.dayOfWeekOfFirstDay();

    for (i = currentDay.get(Calendar.DAY_OF_MONTH); 
         i <= mc.lastDayOfThisMonth().get(Calendar.DAY_OF_MONTH); 
         i++, currentDay = currentDay.addTime(Calendar.DATE, 1))
    {
      tr.addElement(gp.dateSquare(currentDay)).addElement("\n");

      if (mc.isLastDayOfWeek(weekpos)) {
        ec.addElement(tr).addElement("\n");
        tr = emptyWeek(currentDay.addTime(Calendar.DATE, 1));
      }

      weekpos = (weekpos + 1) % mc.daysInWeek();    
    }

    if (!mc.isLastDayOfWeek(weekpos - 1)) {
      tr.addElement(blankDays(numberOfFinalBlankDays())).addElement("\n");
      ec.addElement(tr).addElement("\n");
    }

    return ec;
  }
}
