// java

package uwcal.out;

import java.sql.SQLException;
import java.text.DateFormat;

import org.apache.ecs.AlignType;
import org.apache.ecs.Element;
import org.apache.ecs.html.Table;
import org.apache.ecs.html.TD;
import org.apache.ecs.html.TH;
import org.apache.ecs.html.TR;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.ItemException;

/**
  An object that can create HTML for a month, without showing any events
  @author Greg Barnes
  @version 1.1
 */
public class SmallMonthPrinter extends GridPrinter 
{
  /** The object that prints the grid of days */
  protected Month month;

  /** Prefix to append to URLs */
  private String urlPrefix;

  /** Constructor
    @param mc A <code>MyCalendar</code> of a time within the month to print
    @param es List of events (currently not used) 
    @param urlPrefix prefix to append to URLs.  This allows the object to
      be used outside the main application --- URLs in the main application
      are all relative, so to reference the main application elsewhere, we
      need to prepend an absolute path (and possibly a hostname, port, etc.)
   */
  // urlPrefix is used by calchannel
  protected SmallMonthPrinter(MyCalendar mc, EventsI es, String urlPrefix) 
  {
    super(mc, es);
    this.urlPrefix = urlPrefix;
    month = new SmallMonth(mc, es, this);
  }

  /** Constructor
    @param mc A <code>MyCalendar</code> of a time within the month to print
    @param es List of events (currently not used) 
   */
  protected SmallMonthPrinter(MyCalendar mc, EventsI es) {
    this(mc, es, null);
  }

  /**
    @return HTML for the title of the month
   */
  protected Element monthTitle() 
  {
    return Util.linkItem(Monthview.url(mc, this.urlPrefix), 
                         mc.monthString(), Style.MONTH);
  }

    protected TR monthName() {
        return new TR().
          addElement(new TD().
            setColSpan(mc.daysInWeek() + 1).
            addElement(monthTitle()).addElement("\n").
            setClass(Style.MONTH_NAME_CELL));
    }

    protected TH emptyDayName() {
        return (TH) new TH().setClass(Style.DAY_OF_WEEK_CELL);
    }
 
    protected TR emptyDayNames() {
        return new TR().setAlign(AlignType.RIGHT).addElement(emptyDayName());
    }
 
    protected Element dayOfWeekNameHeading(int weekpos) {
        return emptyDayName().addElement(mc.dayOfWeekAbbr(weekpos));
    }

    protected TD dateSquareTD(MyCalendar date) {
        return new TD();
    }

  /**
    @return HTML for the contents of a single date square
    @param date The date in the square
   */
  protected Element dateSquareContents(MyCalendar date) 
  {
    return Util.linkItem(Dayview.url(date, this.urlPrefix), 
                         date.getComponent(DateFormat.DATE_FIELD), Style.DAY);
  }

  /**
    Get the month, as HTML
    @returns The month as HTML
   */
  protected Element print() 
  {
    try {
      return new Table().setCellSpacing(1).setCellPadding(3).
setWidth("100%").        //%%% for non-compliant browsers
             addElement(monthName()).addElement("\n").
             addElement(dayNames()).addElement("\n").
             addElement(month.monthGrid()).
             addElement("\n").
             setClass(Style.SMALLMONTH_TABLE);
    } catch (ItemException e) {	// shouldn't happen
      throw new RuntimeException("SmallMonthPrinter throws ItemException!");
    } catch (SQLException e) {	// shouldn't happen
      throw new RuntimeException("SmallMonthPrinter throws SQLException!");
    }
  }
}
