// java

package uwcal.out;

import org.apache.ecs.Element;
import org.apache.ecs.StringElement;
import org.apache.ecs.html.A;
import org.apache.ecs.html.Span;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;

/**
  Utility methods
  @author Greg Barnes
  @version 1.2
 */
public class Util 
{
  protected static String getParamName(String name) 
  {
    return "&" + name + "=";
  }

  /** The name of the <code>calendar</code> parameter, in suitable form
      for a GET url */
  public static final String CALENDAR_PARAM = 
      getParamName(CalParameter.CALENDAR);

  public static final String FUNCTION_PARAM = 
    getParamName(CalParameter.FUNCTION);
  public static final String FUNCTION2_PARAM = 
    getParamName(CalParameter.FUNCTION2);
  public static final String DATE_PARAM = getParamName(CalParameter.DATE);
  public static final String EVENT_ID_PARAM = 
    getParamName(CalParameter.EVENT_ID);
  public static final String KEYWORD_ID_PARAM = 
    getParamName(CalParameter.KEYWORD_ID);
  public static final String SPONSOR_ID_PARAM = 
    getParamName(CalParameter.SPONSOR_ID);
  public static final String LOCATION_ID_PARAM = 
    getParamName(CalParameter.LOCATION_ID);
  public static final String IDENTIFIER_PARAM =
    getParamName(CalParameter.IDENTIFIER_NAME);

  /**
    Get a URL for a page that references an entity
    @param base Start of URL
    @param mc The current date
    @parem page This URL is a part of
    @param entityIdName Parameter name for the type of entity referenced
    @param entityIdValue Parameter value for the type of entity referenced
    @param identifierValue ID # of the entity referenced
   */
  public static String makeUrl(String base, 
                               MyCalendar mc,
                               Page page,
                               String entityIdName, 
                               int entityIdValue,
                               int identifierValue)
  {
    return base + mc.getDateDigits() + 
           Util.FUNCTION2_PARAM + page.nextFunction() +
           entityIdName + entityIdValue + IDENTIFIER_PARAM + identifierValue;
  }

  public static Element linkItem(String href, 
                                 Element anchor,
                                 String cl,
                                 String id) 
  {
    A a = new A().setHref(href).addElement(anchor);

    if (cl != null) {
        a.setClass(cl);
    }

    if (id != null) {
        a.setID(id);
    }

    return a;
  }

  public static Element linkItem(String href, Element anchor) 
  {
    return linkItem(href, anchor, null, null);
  }

  public static Element linkItem(String href, 
                                 String anchor, 
                                 String cl,
                                 String id) 
  {
    return linkItem(href, new StringElement(anchor), cl, id);
  }

  public static Element linkItem(String href, String anchor, String cl) 
  {
    return linkItem(href, anchor, cl, null);
  }

  public static Element linkItem(String href, String anchor) 
  {
    return linkItem(href, anchor, null, null);
  }

  /**
    Create a span element
    @param text Text inside the element
    @param cl Class of the element
    @param title Title of the element
    @return The span element
   */
  public static Span spanItem(Element text, String cl, String title) 
  {
    Span s = new Span().addElement(text);

    if (title != null) {
        s.setTitle(title);
    }

    if (cl != null) {
        s.setClass(cl);
    }

    return s;
  }

  /**
    Create a span element
    @param text Text inside the element
    @param cl Class of the element
    @return The span element
   */
  public static Span spanItem(Element text, String cl) 
  {
    return spanItem(text, cl, null);
  }

  /**
    Create a span element
    @param text Text inside the element
    @param cl Class of the element
    @param title Title of the element
    @return The span element
   */
  public static Span spanItem(String text, String cl, String title) 
  {
    return spanItem(new StringElement(text), cl, title);
  }

  /**
    Create a span element
    @param text Text inside the element
    @param cl Class of the element
    @return The span element
   */
  public static Span spanItem(String text, String cl) 
  {
    return spanItem(text, cl, null);
  }

  public static Element description(String s) 
  {
    return spanItem(s, Style.DESCRIPTION);
  }
}

