// java

package uwcal.out;

import java.util.Properties;

import edu.washington.cac.calendar.CalLogFactory;
import edu.washington.cac.calendar.CalProperties;

/**
  'constants' involving URLs and the like

  Constant value that can vary across servers should be in the 
  web.properties file.

  Values that should be the same for all servers are defined below in
  the usual way.

  @author Greg Barnes
  @version 1.0
 */
public class WebResources
{
  /** Location of the properties file */
  private static final String PROPERTIES_FILE = 
      "/properties/calendar/web.properties";

  /** Object to hold properties */
  private static Properties properties = new Properties();

  /** Load properties file */
  static {
    try {
      properties.load(WebResources.class.getResourceAsStream(PROPERTIES_FILE));
    } catch(Exception e) {
      e.printStackTrace(new CalLogFactory().create().getPrintStream());
      new CalLogFactory().create().
          println("Cannot find " + PROPERTIES_FILE);
    }
  }

  /** @return the start of any absolute servlet paths (i.e., the common part 
    of a servlet URL after the protocol/hostname/port) 
   */
  public static String absolutePath() 
  {
    return properties.getProperty("absolutePath");
  }

  /** @return the directory that contains html */
  public static String htmlDir() 
  {
    return properties.getProperty("htmlDir");
  }

  /** @return the directory that contains images */
  public static String imageDir() 
  {
    return properties.getProperty("imageDir");
  }

  /** 
     Get the name of the help file
     @return the name of the help file 
   */
  public static String helpFile() 
  {
    return properties.getProperty("helpFile");
  }

  /** @return the name of the file that holds the application's logo */
  public static String logo() 
  {
    return properties.getProperty("logo");
  }

  /** @return the name of the file that holds the image of a 'previous' arrow */
  public static String prevImg() 
  {
    return properties.getProperty("prevImg");
  }

  /** @return the name of the file that holds the image of a 'next' arrow */
  public static String nextImg() 
  {
    return properties.getProperty("nextImg");
  }

  /** @return the name of the file that holds the image of the 
    'add this event to my calendar' icon
   */
  public static String addrefImg() 
  {
    return properties.getProperty("addrefImg");
  }

  /** 
    Get the URL to enter the public events entry pages
    @return the URL to enter the public events entry pages
   */
  public static String pubeventsEntryUrl() 
  {
    return properties.getProperty("pubeventsEntryUrl");
  }

  /** 
    Get the URL that provides descriptions of categories
    @return the URL that provides descriptions of categories
   */
  public static String categoryHelpUrl() 
  {
    return HELP_DIR + properties.getProperty("categoryHelpUrl");
  }

  /** start of all servlet class names */
  public static final String BASE_URL = "uwcal.";

  /** main servlet URL */
  public static final String BASE_POST_URL = BASE_URL + "UWCal";

  /** base of the servlet URL when using get parameters */
  public static final String BASE_NOPARAM_URL = BASE_POST_URL + "?";

  /** base of the servlet URL when using get parameters, plus the name
    of the function parameter*/
  public static final String BASE_GET_URL = BASE_NOPARAM_URL + 
      Util.FUNCTION_PARAM;

  /** base of the absolute servlet URL path when using get parameters, 
    plus the name of the function parameter
   */
  static final String BASE_ABSOLUTE_GET_PATH = absolutePath() + BASE_GET_URL;

  /** servlet login URL for login */
  public static final String LOGIN_URL = 
      BASE_URL + (CalProperties.defaultIsGuest() ? "guestlogin.GuestLogin" : 
                                                 "userlogin.CalLogin");

  /** URL for a welcome page */
  public static final String WELCOME_URL = htmlDir() + "index.html";

  /** URL for a page explaining the application*/
  static final String ABOUT_URL = htmlDir() + "about.html";

  /** dir for help pages */
  static final String HELP_DIR = htmlDir() + "help/";

  /** URL for a help page */
  static final String HELP_URL = HELP_DIR + helpFile();

  /** URL for the logo */
  static final String LOGO_URL = imageDir() + logo();

  /** URL for the 'previous' arrow */
  static final String PREV_URL = imageDir() + prevImg();

  /** URL for the 'next' arrow */
  static final String NEXT_URL = imageDir() + nextImg();

  /** URL for the 'add this to my calendar' icon */
  static final String ADD_TO_CALENDAR_URL = imageDir() + addrefImg();
}
