// java

package uwcal.out.forms;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.Entities;
import org.apache.ecs.StringElement;
import org.apache.ecs.html.HR;
import org.apache.ecs.html.TD;
import org.apache.ecs.html.TR;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.Location;
import edu.washington.cac.calendar.data.Locations;
import edu.washington.cac.calendar.data.User;

import uwcal.out.Page;
import uwcal.out.Style;
import uwcal.out.Util;

/**
  A form to add an event
  @author Greg Barnes
  @version 1.1
 */
public class AddEventForm extends EventForm 
{
  /** Create a new instance
    @param page Page this form is a part of
    @param ls The user's locations
   */
  public AddEventForm(Page page,
                      Locations ls)
  {
    super(page, null, ls);
  }

  protected String formFunction() 
  {
    return CalParameter.ADDEVENT_FUNC;
  }

  protected String titleText() 
  {
    return FormsDisplayText.ADD_EVENT_TITLE;
  }

  protected Element startHour() 
  {
    return startHourInput(null);
  }

  protected Element endHour() 
  {
    return endHourInput(null);
  }

  protected Element location() {
      return new ElementContainer().
        addElement(CommonFormElements.
          headerRow(FormsDisplayText.LOCATION,
            Style.LOCATION_HEADER)).
        addElement("\n").
        addElement(CommonFormElements.
          tableRowOneCell(locationInput(Location.NO_LOCATION_ID)));
  }

  protected Element startdate() {
      return startDateInput(null);
  }

  protected Element enddate() {
      return endDateInput(null, null);
  }

  protected Element dateTime(Element name, Element date, Element time) {
      return new ElementContainer().
        addElement(CommonFormElements.tableRowTwoCells(name, date)).
        addElement(CommonFormElements.tableRowTwoCells(
          new StringElement(Entities.NBSP), time));
//          new ElementContainer().
//            addElement(name).
//            addElement(date).addElement(new BR()).addElement(time)));
  }

  protected Element dateTimeHeader() {
      return CommonFormElements.headerRow(FormsDisplayText.DATETIME,
        Style.DATETIME_HEADER);
  }

  protected Element dateTimeDivider() {
      return new TR().addElement(new TD().setColSpan(2).
        addElement(new HR().setSize(1).setNoShade(true)));
  }

  protected Element fieldName(String name) {
      return Util.spanItem(name + ":", Style.FIELD_NAME);
  }

  protected Element startDateTime() {
      return dateTime(fieldName(FormsDisplayText.START),
        startdate(), startHour());
  }

  protected Element endDateTime() {
      return dateTime(fieldName(FormsDisplayText.END),
        enddate(), endHour());
  }

  protected String submitButtonText() {
        return FormsDisplayText.ADD_EVENT;
  }
}
